What’s new in version 0.4.4
===========================
Version available since January 20, 2023

Bug fixed
---------
Model
+++++
-Adding an example of modelling of an electric vehicle offering flexibility
when connected to the system (with a corresponding non-regression test).

-Minimal values (1e-5) were replaced to zero, to lighten the problem formulation
(non-necessary binaries are now multiplied by zero so they don't appear in the .lp file),
all non-regression tests passed (with minor modifications : non-exact values due to previous
numerical approximations were corrected from 1e-5 to zero).

Documentation
-------------
- Updating the docs

Contributors
------------

Etienne Cuisinier